==> libcamera-docs-0.6.0-2-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/classlibcamera_1_1MediaDevice.js <==
var classlibcamera_1_1MediaDevice =
[
    [ "MediaDevice", "classlibcamera_1_1MediaDevice.html#ab950a4880c2bea6d94bfd6ecfe46e5f5", null ],
    [ "acquire", "classlibcamera_1_1MediaDevice.html#a02fd5f5a3d81330a87f1ee53511866ef", null ],
    [ "allocateRequests", "classlibcamera_1_1MediaDevice.html#a0b99a0b5057a339a9ce2626d0ddcb64c", null ],
    [ "busy", "classlibcamera_1_1MediaDevice.html#a3f58c03f422e84824a9e2e35afcaa2bb", null ],
    [ "deviceNode", "classlibcamera_1_1MediaDevice.html#a7852411b1edfc2e1160aa345eb6b0317", null ],
    [ "disableLinks", "classlibcamera_1_1MediaDevice.html#a182bb41cfc7fcfa080327f8ff26070f0", null ],
    [ "driver", "classlibcamera_1_1MediaDevice.html#a9401833fd3bc25ba494cf2df92ae3ee1", null ],
    [ "entities", "classlibcamera_1_1MediaDevice.html#a3387ed077b0ecced2ceaa538f47a4a6b", null ],
    [ "getEntityByName", "classlibcamera_1_1MediaDevice.html#ad5d9279329ef4987ceece2694b33e230", null ],
    [ "hwRevision", "classlibcamera_1_1MediaDevice.html#aae64ebdfe69ba9060577951ede91f2d0", null ],
    [ "isValid", "classlibcamera_1_1MediaDevice.html#a284ed335c76a8bb6d2190f1e99180d4e", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#a84ada727fc400e022fb8814191c54869", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#a8ab25ee1197502a3fb2c18d9fbd229a5", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#ab8a926b86f0ae67f56544b10e72cb83f", null ],
    [ "locateEntities", "classlibcamera_1_1MediaDevice.html#a8bf59669c1643ad97b353d9492189c56", null ],
    [ "lock", "classlibcamera_1_1MediaDevice.html#aafab9ceead67be818337139645d3d9f9", null ],
    [ "logPrefix", "classlibcamera_1_1MediaDevice.html#a15b5bc0dc607109830666d53dfe019e5", null ],
    [ "model", "classlibcamera_1_1MediaDevice.html#adadfeebec081f183b703bd72c102791e", null ],
    [ "populate", "classlibcamera_1_1MediaDevice.html#a8fe692b0d3675cff3e162305db246c25", null ],
    [ "release", "classlibcamera_1_1MediaDevice.html#a511ae507d3fffc097e938a7f55eb801c", null ],
    [ "supportsRequests", "classlibcamera_1_1MediaDevice.html#a4f97762ec54d19969919feb7ddb60d82", null ],
    [ "unlock", "classlibcamera_1_1MediaDevice.html#afa3b83f5f3fe2af9b4a8b5d518518386", null ],
    [ "version", "classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8", null ],
    [ "disconnected", "classlibcamera_1_1MediaDevice.html#ac9128298434c9a142fd93539cd6a259d", null ]
];

==> libcamera-docs-0.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/classlibcamera_1_1MediaDevice.js <==
var classlibcamera_1_1MediaDevice =
[
    [ "MediaDevice", "classlibcamera_1_1MediaDevice.html#ab950a4880c2bea6d94bfd6ecfe46e5f5", null ],
    [ "acquire", "classlibcamera_1_1MediaDevice.html#a02fd5f5a3d81330a87f1ee53511866ef", null ],
    [ "allocateRequests", "classlibcamera_1_1MediaDevice.html#a0b99a0b5057a339a9ce2626d0ddcb64c", null ],
    [ "busy", "classlibcamera_1_1MediaDevice.html#a3f58c03f422e84824a9e2e35afcaa2bb", null ],
    [ "deviceNode", "classlibcamera_1_1MediaDevice.html#a7852411b1edfc2e1160aa345eb6b0317", null ],
    [ "disableLinks", "classlibcamera_1_1MediaDevice.html#a182bb41cfc7fcfa080327f8ff26070f0", null ],
    [ "driver", "classlibcamera_1_1MediaDevice.html#a9401833fd3bc25ba494cf2df92ae3ee1", null ],
    [ "entities", "classlibcamera_1_1MediaDevice.html#a3387ed077b0ecced2ceaa538f47a4a6b", null ],
    [ "getEntityByName", "classlibcamera_1_1MediaDevice.html#a19b616e7e4eb823362a42594d00c64fa", null ],
    [ "getEntityByName", "classlibcamera_1_1MediaDevice.html#ad5d9279329ef4987ceece2694b33e230", null ],
    [ "hwRevision", "classlibcamera_1_1MediaDevice.html#aae64ebdfe69ba9060577951ede91f2d0", null ],
    [ "isValid", "classlibcamera_1_1MediaDevice.html#a284ed335c76a8bb6d2190f1e99180d4e", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#a84ada727fc400e022fb8814191c54869", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#a8ab25ee1197502a3fb2c18d9fbd229a5", null ],
    [ "link", "classlibcamera_1_1MediaDevice.html#ab8a926b86f0ae67f56544b10e72cb83f", null ],
    [ "locateEntities", "classlibcamera_1_1MediaDevice.html#a8bf59669c1643ad97b353d9492189c56", null ],
    [ "lock", "classlibcamera_1_1MediaDevice.html#aafab9ceead67be818337139645d3d9f9", null ],
    [ "logPrefix", "classlibcamera_1_1MediaDevice.html#a15b5bc0dc607109830666d53dfe019e5", null ],
    [ "model", "classlibcamera_1_1MediaDevice.html#adadfeebec081f183b703bd72c102791e", null ],
    [ "populate", "classlibcamera_1_1MediaDevice.html#a8fe692b0d3675cff3e162305db246c25", null ],
    [ "release", "classlibcamera_1_1MediaDevice.html#a511ae507d3fffc097e938a7f55eb801c", null ],
    [ "supportsRequests", "classlibcamera_1_1MediaDevice.html#a4f97762ec54d19969919feb7ddb60d82", null ],
    [ "unlock", "classlibcamera_1_1MediaDevice.html#afa3b83f5f3fe2af9b4a8b5d518518386", null ],
    [ "version", "classlibcamera_1_1MediaDevice.html#af335184ee6174ea68747d32955d6f9c8", null ],
    [ "disconnected", "classlibcamera_1_1MediaDevice.html#ac9128298434c9a142fd93539cd6a259d", null ]
];
